==> generator-angular2-firebase-bootstrap-1.0.3.tgz: package/generators/app/templates/src/app/shared/auth.service.ts <==
import {Injectable, EventEmitter, Output} from "@angular/core";
import {User} from "firebase";
import {AngularFireAuth, AuthProviders, AuthMethods} from "angularfire2";
import {BehaviorSubject} from "rxjs/BehaviorSubject";
import {UserInfo} from "./user-info";
import {Observable, Subject, ReplaySubject, AsyncSubject} from "rxjs";

@Injectable()
export class AuthService {
    private userInfoSubject: ReplaySubject<UserInfo>;
    private auth: User;

    constructor(private angularFireAuth: AngularFireAuth) {
        this.initUserInfoSubject();
        // console.log("AuthService");
        angularFireAuth.subscribe(auth => {
            // console.log("auth: ", JSON.stringify(auth));
            let userInfo = new UserInfo();
            if (auth != null) {
                this.auth = auth.auth;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.isAnonymous = auth.auth.isAnonymous;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.email = auth.auth.email;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.displayName = auth.auth.displayName;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.providerId = auth.auth.providerId;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.photoURL = auth.auth.photoURL;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.uid = auth.auth.uid;
            } else {
                this.auth = null;
                userInfo.isAnonymous = true;
            }
            console.log("AuthService: ", userInfo);
            this.userInfoSubject.next(userInfo);
        });
    }

    login(email: string, password: string) {
        console.log("login: ", email);
        this.initUserInfoSubject();
        this.angularFireAuth.login({email: email, password: password});
    }

    private initUserInfoSubject() {
        this.userInfoSubject = new ReplaySubject<UserInfo>(1);
    }

    currentUser(): Observable<UserInfo> {
        return this.userInfoSubject.asObservable();
    }

    logout() {
        console.log("logout()");
        this.initUserInfoSubject();
        this.angularFireAuth.logout();
    }

    isLoggedIn(): Observable<boolean> {
        console.log("isLoggedIn?");
        let isLoggedInBS = new AsyncSubject<boolean>();
        this.userInfoSubject.subscribe(ui => {
            // console.log("isLoggedIn: anonymous=" + ui.isAnonymous);
                isLoggedInBS.next(!ui.isAnonymous);
                isLoggedInBS.complete();
            // setTimeout(() => {
            // }, 0);
        });
        return isLoggedInBS;
    }

    updateDisplayName(displayName: string): Observable<string> {
        console.log("updateDisplayName: ", displayName);
        let result = new Subject<string>();
        //noinspection TypeScriptUnresolvedFunction
        this.auth.updateProfile({displayName: displayName, photoURL: null}).then(a => {
            result.next("success");
        }).catch(err => result.error(err));
        return result;
    }

    createUser(email: string, password: string, displayName: string) {
        console.log("createUser: email=" + email + " displayName: " + displayName);
        //noinspection TypeScriptUnresolvedFunction
        this.angularFireAuth.createUser({email: email, password: password})
            .then(auth => auth.auth.updateProfile({displayName: displayName, photoURL: null}));
    }

    updateEmail(email: string): Observable<string> {
        console.log("updateEmail: ", email);
        let result = new Subject<string>();
        //noinspection TypeScriptUnresolvedFunction
        this.auth.updateEmail(email).then(a => {
            result.next("success");
        }).catch(err => result.error(err));
        return result.asObservable();
    }

    updatePassword(password: string): Observable<string> {
        console.log("updatePassword: ", password);
        let result = new Subject<string>();
        //noinspection TypeScriptUnresolvedFunction
        this.auth.updatePassword(password).then(a => {
            result.next("success");
        }).catch(err => result.error(err));
        return result.asObservable();
    }

    loginViaProvider(provider: string): Observable<String> {
        let result = new Subject<string>();
        if (provider === "google") {
            //noinspection TypeScriptUnresolvedFunction
            this.angularFireAuth
                .login({provider: AuthProviders.Google, method: AuthMethods.Popup})
                //noinspection TypeScriptUnresolvedFunction
                .  //noinspection TypeScriptUnresolvedFunction
                then(auth => result.next("success"))
                        .catch(err => result.error(err));
            return result.asObservable();
        }
        else if (provider === "twitter") {
            //noinspection TypeScriptUnresolvedFunction
            this.angularFireAuth
                .login({provider: AuthProviders.Twitter, method: AuthMethods.Popup})
                //noinspection TypeScriptUnresolvedFunction
                .  //noinspection TypeScriptUnresolvedFunction
                then(auth => result.next("success"))
                        .catch(err => result.error(err));
            return result.asObservable();
        }
        result.error("Not a supported authentication method: " + provider)
        return result.asObservable();
    }
}

==> generator-angular2-firebase-bootstrap-1.0.6.tgz: package/generators/app/templates/src/app/shared/auth.service.ts <==
import {Injectable, EventEmitter, Output} from "@angular/core";
import {User} from "firebase";
import {AngularFireAuth, AuthProviders, AuthMethods} from "angularfire2";
import {BehaviorSubject} from "rxjs/BehaviorSubject";
import {UserInfo} from "./user-info";
import {Observable, Subject, ReplaySubject, AsyncSubject} from "rxjs";

@Injectable()
export class AuthService {
    private userInfoSubject: ReplaySubject<UserInfo>;
    private auth: User;

    constructor(private angularFireAuth: AngularFireAuth) {
        this.initUserInfoSubject();
        // console.log("AuthService");
        angularFireAuth.subscribe(auth => {
            // console.log("auth: ", JSON.stringify(auth));
            let userInfo = new UserInfo();
            if (auth != null) {
                this.auth = auth.auth;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.isAnonymous = auth.auth.isAnonymous;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.email = auth.auth.email;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.displayName = auth.auth.displayName;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.providerId = auth.auth.providerId;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.photoURL = auth.auth.photoURL;
                //noinspection TypeScriptUnresolvedVariable
                userInfo.uid = auth.auth.uid;
            } else {
                this.auth = null;
                userInfo.isAnonymous = true;
            }
            this.userInfoSubject.next(userInfo);
        });
    }

    login(email: string, password: string) {
        // console.log("login: ", email);
        this.initUserInfoSubject();
        this.angularFireAuth.login({email: email, password: password});
    }

    private initUserInfoSubject() {
        this.userInfoSubject = new ReplaySubject<UserInfo>(1);
    }

    currentUser(): Observable<UserInfo> {
        return this.userInfoSubject.asObservable();
    }

    logout() {
        this.initUserInfoSubject();
        this.angularFireAuth.logout();
    }

    isLoggedIn(): Observable<boolean> {
        let isLoggedInBS = new AsyncSubject<boolean>();
        this.userInfoSubject.subscribe(ui => {
            // console.log("isLoggedIn: anonymous=" + ui.isAnonymous);
                isLoggedInBS.next(!ui.isAnonymous);
                isLoggedInBS.complete();
            // setTimeout(() => {
            // }, 0);
        });
        return isLoggedInBS;
    }

    updateDisplayName(displayName: string): Observable<string> {
        let result = new Subject<string>();
        //noinspection TypeScriptUnresolvedFunction
        this.auth.updateProfile({displayName: displayName, photoURL: null}).then(a => {
            result.next("success");
        }).catch(err => result.error(err));
        return result;
    }

    createUser(email: string, password: string, displayName: string) {
        //noinspection TypeScriptUnresolvedFunction
        this.angularFireAuth.createUser({email: email, password: password})
            .then(auth => auth.auth.updateProfile({displayName: displayName, photoURL: null}));
    }

    updateEmail(email: string): Observable<string> {
        let result = new Subject<string>();
        //noinspection TypeScriptUnresolvedFunction
        this.auth.updateEmail(email).then(a => {
            result.next("success");
        }).catch(err => result.error(err));
        return result.asObservable();
    }

    updatePassword(password: string): Observable<string> {
        let result = new Subject<string>();
        //noinspection TypeScriptUnresolvedFunction
        this.auth.updatePassword(password).then(a => {
            result.next("success");
        }).catch(err => result.error(err));
        return result.asObservable();
    }

    loginViaProvider(provider: string): Observable<String> {
        let result = new Subject<string>();
        if (provider === "google") {
            //noinspection TypeScriptUnresolvedFunction
            this.angularFireAuth
                .login({provider: AuthProviders.Google, method: AuthMethods.Popup})
                //noinspection TypeScriptUnresolvedFunction
                .  //noinspection TypeScriptUnresolvedFunction
                then(auth => result.next("success"))
                        .catch(err => result.error(err));
            return result.asObservable();
        }
        else if (provider === "twitter") {
            //noinspection TypeScriptUnresolvedFunction
            this.angularFireAuth
                .login({provider: AuthProviders.Twitter, method: AuthMethods.Popup})
                //noinspection TypeScriptUnresolvedFunction
                .  //noinspection TypeScriptUnresolvedFunction
                then(auth => result.next("success"))
                        .catch(err => result.error(err));
            return result.asObservable();
        }
        result.error("Not a supported authentication method: " + provider)
        return result.asObservable();
    }
}
